# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from marly import Marly, AsyncMarly
from tests.utils import assert_matches_type
from marly.types.integrations import (
    SourceRegisterS3Response,
    SourceRegisterLocalFsResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSources:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_register_local_fs(self, client: Marly) -> None:
        source = client.integrations.sources.register_local_fs(
            base_path="string",
        )
        assert_matches_type(SourceRegisterLocalFsResponse, source, path=["response"])

    @parametrize
    def test_raw_response_register_local_fs(self, client: Marly) -> None:
        response = client.integrations.sources.with_raw_response.register_local_fs(
            base_path="string",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        source = response.parse()
        assert_matches_type(SourceRegisterLocalFsResponse, source, path=["response"])

    @parametrize
    def test_streaming_response_register_local_fs(self, client: Marly) -> None:
        with client.integrations.sources.with_streaming_response.register_local_fs(
            base_path="string",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            source = response.parse()
            assert_matches_type(SourceRegisterLocalFsResponse, source, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_method_register_s3(self, client: Marly) -> None:
        source = client.integrations.sources.register_s3(
            aws_access_key="string",
            aws_secret_key="string",
            bucket_name="string",
            region_name="string",
        )
        assert_matches_type(SourceRegisterS3Response, source, path=["response"])

    @parametrize
    def test_raw_response_register_s3(self, client: Marly) -> None:
        response = client.integrations.sources.with_raw_response.register_s3(
            aws_access_key="string",
            aws_secret_key="string",
            bucket_name="string",
            region_name="string",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        source = response.parse()
        assert_matches_type(SourceRegisterS3Response, source, path=["response"])

    @parametrize
    def test_streaming_response_register_s3(self, client: Marly) -> None:
        with client.integrations.sources.with_streaming_response.register_s3(
            aws_access_key="string",
            aws_secret_key="string",
            bucket_name="string",
            region_name="string",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            source = response.parse()
            assert_matches_type(SourceRegisterS3Response, source, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncSources:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_register_local_fs(self, async_client: AsyncMarly) -> None:
        source = await async_client.integrations.sources.register_local_fs(
            base_path="string",
        )
        assert_matches_type(SourceRegisterLocalFsResponse, source, path=["response"])

    @parametrize
    async def test_raw_response_register_local_fs(self, async_client: AsyncMarly) -> None:
        response = await async_client.integrations.sources.with_raw_response.register_local_fs(
            base_path="string",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        source = await response.parse()
        assert_matches_type(SourceRegisterLocalFsResponse, source, path=["response"])

    @parametrize
    async def test_streaming_response_register_local_fs(self, async_client: AsyncMarly) -> None:
        async with async_client.integrations.sources.with_streaming_response.register_local_fs(
            base_path="string",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            source = await response.parse()
            assert_matches_type(SourceRegisterLocalFsResponse, source, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_method_register_s3(self, async_client: AsyncMarly) -> None:
        source = await async_client.integrations.sources.register_s3(
            aws_access_key="string",
            aws_secret_key="string",
            bucket_name="string",
            region_name="string",
        )
        assert_matches_type(SourceRegisterS3Response, source, path=["response"])

    @parametrize
    async def test_raw_response_register_s3(self, async_client: AsyncMarly) -> None:
        response = await async_client.integrations.sources.with_raw_response.register_s3(
            aws_access_key="string",
            aws_secret_key="string",
            bucket_name="string",
            region_name="string",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        source = await response.parse()
        assert_matches_type(SourceRegisterS3Response, source, path=["response"])

    @parametrize
    async def test_streaming_response_register_s3(self, async_client: AsyncMarly) -> None:
        async with async_client.integrations.sources.with_streaming_response.register_s3(
            aws_access_key="string",
            aws_secret_key="string",
            bucket_name="string",
            region_name="string",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            source = await response.parse()
            assert_matches_type(SourceRegisterS3Response, source, path=["response"])

        assert cast(Any, response.is_closed) is True
